@@ -63,7 +63,7 @@ function (y, trt, DFerror, MSerror, alpha=0.05, group=TRUE,main = NULL,console=F
 	}
 	REGW <- Tprob * sdtdif
 	names(REGW)<-2:ntr
-	if(console){cat("\nalpha:",alpha,"; Df Error:",DFerror,"\n")
+	if(console){cat("\nAlpha:",alpha,"; DF Error:",DFerror,"\n")
 	cat("\nCritical Range\n")
 	print(REGW)}
 	if (length(nr) > 1) {
