@@ -1,4 +1,4 @@
-`intervals.freq` <-
+intervals.freq <-
 function(x){
 if(class(x)[1]=="graph.freq" | class(x)[1]=="histogram")breaks<-x$breaks
 if(class(x)[1]=="numeric" | class(x)[1]=="integer"  )breaks<-x
@@ -12,4 +12,3 @@ classes[i,2]<-breaks[i+1]
 colnames(classes)<-c("lower","upper")
 return(classes)
 }
-
